==> cognitocurl-0.1.4.tgz: package/lib/index.js <==
"use strict";
const command_1 = require("@oclif/command");
const cognito_1 = require("./cognito");
const child_process_1 = require("child_process");
const node_fetch_1 = require("node-fetch");
global.fetch = node_fetch_1.default;
class cognitocurl extends command_1.Command {
    async run() {
        const { flags } = this.parse(cognitocurl);
        const cognitoSetup = {
            UserPoolId: flags.userpool,
            ClientId: flags.cognitoclient,
            reset: flags.reset,
            storage: flags.storage
        };
        const { run: command, header = "Authorization", hostedui } = flags;
        try {
            const token = hostedui
                ? await cognito_1.getToken({ hostedUI: hostedui })
                : await cognito_1.getToken(cognitoSetup);
            const signedCommand = `${command} -H '${header}: ${token}' -s`;
            child_process_1.exec(signedCommand, (err, stdout, stderr) => {
                this.log(stdout, stderr);
                process.exit();
            });
        }
        catch (error) {
            this.log(error);
            return true;
        }
    }
}
cognitocurl.description = "describe the command here";
cognitocurl.flags = {
    version: command_1.flags.version({ char: "v" }),
    help: command_1.flags.help(),
    userpool: command_1.flags.string({ description: "Congito User Pool ID" }),
    cognitoclient: command_1.flags.string({ description: "Cognito Client App ID" }),
    reset: command_1.flags.boolean({ description: "Reset Cognito credentials" }),
    hostedui: command_1.flags.string({
        description: "Point to json with hosted ui config. If set, hosted ui will be launched."
    }),
    storage: command_1.flags.string({
        description: "Persistent storage catalogue. Defaults to '/var/tmp'. "
    }),
    header: command_1.flags.string({
        description: "Name HTTP header with authorization token. Defaults to 'Authorization'"
    }),
    run: command_1.flags.string({
        description: "Command to be runned and  sign with -H Autorization token"
    })
};
cognitocurl.strict = false;
module.exports = cognitocurl;

==> cognitocurl-0.1.6.tgz: package/lib/index.js <==
"use strict";
const command_1 = require("@oclif/command");
const cognito_1 = require("./cognito");
const child_process_1 = require("child_process");
const node_fetch_1 = require("node-fetch");
global.fetch = node_fetch_1.default;
class cognitocurl extends command_1.Command {
    async run() {
        const { flags } = this.parse(cognitocurl);
        const cognitoSetup = {
            UserPoolId: flags.userpool,
            ClientId: flags.cognitoclient,
            reset: flags.reset,
            storage: flags.storage
        };
        const { run: command, header = "Authorization", hostedui, token } = flags;
        try {
            const token = hostedui
                ? await cognito_1.getToken({ hostedUI: hostedui })
                : await cognito_1.getToken(cognitoSetup);
            if (token) {
                this.log(token);
                process.exit(0);
            }
            else {
                const signedCommand = `${command} -H '${header}: ${token}' -s`;
                child_process_1.exec(signedCommand, (err, stdout, stderr) => {
                    this.log(stdout, stderr);
                    process.exit();
                });
            }
        }
        catch (error) {
            this.log(error);
            return true;
        }
    }
}
cognitocurl.description = "describe the command here";
cognitocurl.flags = {
    version: command_1.flags.version({ char: "v" }),
    help: command_1.flags.help(),
    userpool: command_1.flags.string({ description: "Congito User Pool ID" }),
    cognitoclient: command_1.flags.string({ description: "Cognito Client App ID" }),
    reset: command_1.flags.boolean({ description: "Reset Cognito credentials" }),
    hostedui: command_1.flags.string({
        description: "Point to json with hosted ui config. If set, hosted ui will be launched."
    }),
    storage: command_1.flags.string({
        description: "Persistent storage catalogue. Defaults to '/var/tmp'. "
    }),
    header: command_1.flags.string({
        description: "Name HTTP header with authorization token. Defaults to 'Authorization'"
    }),
    run: command_1.flags.string({
        description: "Command to be runned and  sign with -H Autorization token"
    }),
    token: command_1.flags.boolean({
        description: "Token to stdout instead of running a curl command"
    })
};
cognitocurl.strict = false;
module.exports = cognitocurl;
